SimplEInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: SimplEInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SimplEInteraction.entity_shape
      ~SimplEInteraction.relation_shape

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_shape
   .. autoattribute:: relation_shape
